@@ -1,4 +1,4 @@
-from ..data import Event
+from ..data import MarketDataEvent
 from ..enums import ChannelType
 from ..enums import EventType
 from .handler import Handler
@@ -6,7 +6,7 @@ from .handler import Handler
 
 class TickerHandler(Handler):
 
-    def __call__(self, event: Event) -> None:
+    def __call__(self, event: MarketDataEvent) -> None:
         if event.channel_type != ChannelType.TICKER:
             return
 
@@ -15,7 +15,7 @@ class TickerHandler(Handler):
 
 class TickerSnapshotHandler(TickerHandler):
 
-    def __call__(self, event: Event) -> None:
+    def __call__(self, event: MarketDataEvent) -> None:
         if event.event_type != EventType.SNAPSHOT:
             return
 
@@ -24,7 +24,7 @@ class TickerSnapshotHandler(TickerHandler):
 
 class TickerUpdateHandler(TickerHandler):
 
-    def __call__(self, event: Event) -> None:
+    def __call__(self, event: MarketDataEvent) -> None:
         if event.event_type != EventType.UPDATE:
             return
 
